# -*- coding: utf-8 -*-
#这里是引用库
# from .config import *
from .bilstm import BiLSTMAttention


